==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fldifimport.1.2.1-1.2.0.tar.gz: ldifimport/ldifimport_opt.php <==
<?php
   /**
    **  ldifimport_opt.php ver 1.2
    **  (c)2001 Nic Bernstein, for iTech, Inc.
    **  (c)2002 Nic Bernstein, for Onlight, llc.
    **
    **  Displays all options relating to importing an LDIF address book
    **
    **/

   chdir('..');
   
   include_once('../src/validate.php');
   include_once('../functions/page_header.php');
   include_once('../functions/display_messages.php');
   include_once('../src/load_prefs.php');

   displayPageHeader($color, 'None');

?>
    <br>
    <table width="95%" align="center" border="0" cellpadding="2" cellspacing="0">
      <tr>
        <td bgcolor="<?php echo $color[0] ?>">
          <center>
            <b><?php echo _("Options") ?> - Address Book Import</b>
          </center>
        </td>
      </tr>
    </table>
    <p>
    This page will allow you to import an address book from another 
    e-mail application into <b><?PHP echo $org_name ?></b>.
    </p><p>
    This importer understands the <b>LDIF</b> file format as defined in 
    <a href="ftp://ftp.isi.edu/in-notes/rfc2849.txt" target="blank">
      RFC-2849
    </a>.
    Many e-mail programs, such as Netscape Communicator, will export 
    address books in LDIF format.
    </p><p>
    If your program does not, then use the address book converter at
    <a href="http://www.interguru.com/mailconv.htm" target="_blank">
       www.interguru.com
    </a>
    to convert your address book into LDIF format, and then import it here.
    </p><p>
    Use the <b>File</b> dialog below to select the address book file.

    <form action="ldifimport.php" method="post" ENCTYPE="multipart/form-data">
      <table width="100%" cellpadding="0" cellspacing="2" border="0">
        <tr>
            <td align="right" nowrap>&nbsp
            </td>
            <td>
               <b>Address Book Filename</b>
               <input type="file" name="fname" size="48">
            </td>
         </tr>
         <tr>
            <td>&nbsp;
            </td>
            <td>
               <input type="submit" value="Submit" name="submit_ldifimport">
            </td>
         </tr>
      </table>   
    </form>
  </body>
</html>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fldifimport.1.3-1.2.0.tar.gz: ldifimport/ldifimport_opt.php <==
<?php
   /**
    **  ldifimport_opt.php ver 1.2
    **  (c)2001 Nic Bernstein, for iTech, Inc.
    **  (c)2002 Nic Bernstein, for Onlight, llc.
    **
    **  Displays all options relating to importing an LDIF address book
    **
    **/

chdir('..');
define('SM_PATH','../');



// include compatibility plugin
//
if (defined('SM_PATH'))
   include_once(SM_PATH . 'plugins/compatibility/functions.php');
else if (file_exists('../plugins/compatibility/functions.php'))
   include_once('../plugins/compatibility/functions.php');
else if (file_exists('./plugins/compatibility/functions.php'))
   include_once('./plugins/compatibility/functions.php');



if (compatibility_check_sm_version(1, 3))
{
   include_once (SM_PATH . 'include/validate.php');
   include_once (SM_PATH . 'functions/page_header.php');
   include_once (SM_PATH . 'functions/display_messages.php');
   include_once (SM_PATH . 'include/load_prefs.php');
}
else
{
   include_once ('../src/validate.php');
   include_once ('../functions/page_header.php');
   include_once ('../functions/display_messages.php');
   include_once ('../src/load_prefs.php');
}




   displayPageHeader($color, 'None');

?>
    <br>
    <table width="95%" align="center" border="0" cellpadding="2" cellspacing="0">
      <tr>
        <td bgcolor="<?php echo $color[0] ?>">
          <center>
            <b><?php echo _("Options") ?> - Address Book Import</b>
          </center>
        </td>
      </tr>
    </table>
    <p>
    This page will allow you to import an address book from another 
    e-mail application into <b><?PHP echo $org_name ?></b>.
    </p><p>
    This importer understands the <b>LDIF</b> file format as defined in 
    <a href="ftp://ftp.isi.edu/in-notes/rfc2849.txt" target="blank">
      RFC-2849
    </a>.
    Many e-mail programs, such as Netscape Communicator, will export 
    address books in LDIF format.
    </p><p>
    If your program does not, then use the address book converter at
    <a href="http://www.interguru.com/mailconv.htm" target="_blank">
       www.interguru.com
    </a>
    to convert your address book into LDIF format, and then import it here.
    </p><p>
    Use the <b>File</b> dialog below to select the address book file.

    <form action="ldifimport.php" method="post" ENCTYPE="multipart/form-data">
      <table width="100%" cellpadding="0" cellspacing="2" border="0">
        <tr>
            <td align="right" nowrap>&nbsp
            </td>
            <td>
               <b>Address Book Filename</b>
               <input type="file" name="fname" size="48">
            </td>
         </tr>
         <tr>
            <td>&nbsp;
            </td>
            <td>
               <input type="submit" value="Submit" name="submit_ldifimport">
            </td>
         </tr>
      </table>   
    </form>
  </body>
</html>
